fn record_replay_failure(
slot: &mut Option<ReplayFailure>,
failure: ReplayFailure,
)Expand description
Records failure as the representative failure for an observation, preferring
terminal failures over non-terminal handler bugs and keeping the first of each class.